Welcome to Under The Sea's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing
   api
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
